@@ -37,7 +37,9 @@
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-preferences.h>
 #include <eel/eel-string.h>
+#include <eel/eel-stock-dialogs.h>
 #include <eel/eel-vfs-extensions.h>
+#include <gtk/gtkmain.h>
 #include <gtk/gtkcellrendererpixbuf.h>
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkscrolledwindow.h>
@@ -48,6 +50,7 @@
 #include <gtk/gtkimage.h>
 #include <gtk/gtkimagemenuitem.h>
 #include <gtk/gtkseparatormenuitem.h>
+#include <gtk/gtklabel.h>
 #include <gtk/gtkmenu.h>
 #include <gtk/gtkmenushell.h>
 #include <gtk/gtkclipboard.h>
@@ -64,9 +67,20 @@
 #include <libnautilus-private/nautilus-tree-view-drag-dest.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
 #include <libnautilus-private/nautilus-cell-renderer-pixbuf-emblem.h>
+#include <libnautilus-private/nautilus-sidebar-provider.h>
+#include <libnautilus-private/nautilus-module.h>
+
+typedef struct {
+        GObject parent;
+} FMTreeViewProvider;
+
+typedef struct {
+        GObjectClass parent;
+} FMTreeViewProviderClass;
+
 
 struct FMTreeViewDetails {
-	GtkWidget *scrolled_window;
+	NautilusWindowInfo *window;
 	GtkTreeView *tree_widget;
 	GtkTreeModelSort *sort_model;
 	FMTreeModel *child_model;
@@ -91,7 +105,11 @@ struct FMTreeViewDetails {
 	GtkWidget *popup_rename;
 	GtkWidget *popup_trash;
 	GtkWidget *popup_properties;
+	GtkWidget *popup_unmount_separator;
+	GtkWidget *popup_unmount;
 	NautilusFile *popup_file;
+	
+	guint selection_changed_timer;
 };
 
 typedef struct {
@@ -109,8 +127,18 @@ static const GtkTargetEntry clipboard_targets[] = {
 	{ "x-special/gnome-copied-files", 0, GNOME_COPIED_FILES },
 };
 
-BONOBO_CLASS_BOILERPLATE (FMTreeView, fm_tree_view,
-			  NautilusView, NAUTILUS_TYPE_VIEW)
+static void  fm_tree_view_iface_init        (NautilusSidebarIface         *iface);
+static void  sidebar_provider_iface_init    (NautilusSidebarProviderIface *iface);
+static GType fm_tree_view_provider_get_type (void);
+
+G_DEFINE_TYPE_WITH_CODE (FMTreeView, fm_tree_view, GTK_TYPE_SCROLLED_WINDOW,
+			 G_IMPLEMENT_INTERFACE (NAUTILUS_TYPE_SIDEBAR,
+						fm_tree_view_iface_init));
+#define parent_class fm_tree_view_parent_class
+
+G_DEFINE_TYPE_WITH_CODE (FMTreeViewProvider, fm_tree_view_provider, G_TYPE_OBJECT,
+			 G_IMPLEMENT_INTERFACE (NAUTILUS_TYPE_SIDEBAR_PROVIDER,
+						sidebar_provider_iface_init));
 
 static gboolean
 show_iter_for_file (FMTreeView *view, NautilusFile *file, GtkTreeIter *iter)
@@ -220,6 +248,16 @@ schedule_show_selection (FMTreeView *view)
 	}
 }
 
+static void
+schedule_select_and_show_location (FMTreeView *view, char *location)
+{
+	if (view->details->selection_location != NULL) {
+		g_free (view->details->selection_location);
+	}
+	view->details->selection_location = g_strdup (location);
+	schedule_show_selection (view);
+}
+
 static void
 row_loaded_callback (GtkTreeModel     *tree_model,
 		     GtkTreeIter      *iter,
@@ -285,7 +323,7 @@ got_activation_uri_callback (NautilusFile *file, gpointer callback_data)
         char *uri, *file_uri;
         FMTreeView *view;
 	GdkScreen *screen;
-	Nautilus_ViewFrame_OpenMode mode;
+	NautilusWindowOpenMode mode;
 	
         view = FM_TREE_VIEW (callback_data);
 
@@ -293,7 +331,7 @@ got_activation_uri_callback (NautilusFile *file, gpointer callback_data)
 
         g_assert (file == view->details->activation_file);
         
-        mode = view->details->activation_in_new_window ? Nautilus_ViewFrame_OPEN_IN_NAVIGATION : Nautilus_ViewFrame_OPEN_ACCORDING_TO_MODE;
+        mode = view->details->activation_in_new_window ? NAUTILUS_WINDOW_OPEN_IN_NAVIGATION : NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE;
 
 	/* FIXME: reenable && !eel_uris_match_ignore_fragments (view->details->current_main_view_uri, uri) */
 
@@ -320,8 +358,8 @@ got_activation_uri_callback (NautilusFile *file, gpointer callback_data)
 
 		/* Non-local executables don't get launched. They act like non-executables. */
 		if (file_uri == NULL) {
-			nautilus_view_open_location
-				(NAUTILUS_VIEW (view), 
+			nautilus_window_info_open_location
+				(view->details->window, 
 				 uri, 
 				 mode,
 				 0,
@@ -338,8 +376,8 @@ got_activation_uri_callback (NautilusFile *file, gpointer callback_data)
 				g_free (view->details->selection_location);
 			}
 			view->details->selection_location = g_strdup (uri);
-			nautilus_view_open_location
-				(NAUTILUS_VIEW (view), 
+			nautilus_window_info_open_location
+				(view->details->window, 
 				 uri,
 				 mode,
 				 0,
@@ -378,34 +416,64 @@ row_activated_callback (GtkTreeView *treeview, GtkTreePath *path,
 	}
 }
 
-
-static void
-selection_changed_callback (GtkTreeSelection *selection,
-			    FMTreeView *view)
+static gboolean 
+selection_changed_timer_callback(FMTreeView *view)
 {
 	NautilusFileAttributes attributes;
 	GtkTreeIter iter;
+	GtkTreeSelection *selection;
+	
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view->details->tree_widget));
 
 	/* no activation if popup menu is open */
 	if (view->details->popup_file != NULL) {
-		return;
+		return FALSE;
 	}
 
 	cancel_activation (view);
 
 	if (!gtk_tree_selection_get_selected (selection, NULL, &iter)) {
-		return;
+		return FALSE;
 	}
 
 	view->details->activation_file = sort_model_iter_to_file (view, &iter);
 	if (view->details->activation_file == NULL) {
-		return;
+		return FALSE;
 	}
 	view->details->activation_in_new_window = FALSE;
 		
 	attributes = NAUTILUS_FILE_ATTRIBUTE_ACTIVATION_URI;
 	nautilus_file_call_when_ready (view->details->activation_file, attributes,
 				       got_activation_uri_callback, view);
+	return FALSE; /* remove timeout */
+}
+
+static void
+selection_changed_callback (GtkTreeSelection *selection,
+			    FMTreeView *view)
+{
+	GdkEvent *event;
+	gboolean is_keyboard;
+
+	if (view->details->selection_changed_timer) {
+		g_source_remove (view->details->selection_changed_timer);
+		view->details->selection_changed_timer = 0;
+	}
+	
+	event = gtk_get_current_event ();
+	if (event) {
+		is_keyboard = (event->type == GDK_KEY_PRESS || event->type == GDK_KEY_RELEASE);
+		gdk_event_free (event);
+
+		if (is_keyboard) {
+			/* on keyboard event: delay the change */
+			/* TODO: make dependent on keyboard repeat rate as per Markus Bertheau ? */
+			view->details->selection_changed_timer = g_timeout_add (300, (GSourceFunc) selection_changed_timer_callback, view);
+		} else {
+			/* on mouse event: show the change immediately */
+			selection_changed_timer_callback (view);
+		}
+	}
 }
 
 static int
@@ -520,8 +588,8 @@ add_root_for_volume (FMTreeView *view,
 	mount_uri = gnome_vfs_volume_get_activation_uri (volume);
 	name = gnome_vfs_volume_get_display_name (volume);
 	
-	fm_tree_model_add_root_uri (view->details->child_model,
-					  mount_uri, name, icon);
+	fm_tree_model_add_root_uri(view->details->child_model,
+				   mount_uri, name, icon, volume);
 
 	g_free (icon);
 	g_free (name);
@@ -612,6 +680,19 @@ can_move_uri_to_trash (const char *file_uri_string)
 	return result;
 }
 
+static gboolean
+eject_for_type (GnomeVFSDeviceType type)
+{
+	switch (type) {
+	case GNOME_VFS_DEVICE_TYPE_CDROM:
+	case GNOME_VFS_DEVICE_TYPE_ZIP:
+	case GNOME_VFS_DEVICE_TYPE_JAZ:
+		return TRUE;
+	default:
+		return FALSE;
+	}
+}
+
 static gboolean
 button_pressed_callback (GtkTreeView *treeview, GdkEventButton *event,
 			 FMTreeView *view)
@@ -620,6 +701,10 @@ button_pressed_callback (GtkTreeView *treeview, GdkEventButton *event,
 	char *uri;
 
 	if (event->button == 3) {
+		gboolean unmount_is_eject = FALSE;
+		gboolean show_unmount = FALSE;
+		GnomeVFSVolume *volume = NULL;
+		
 		if (!gtk_tree_view_get_path_at_pos (treeview, event->x, event->y,
 						    &path, NULL, NULL, NULL)) {
 			return FALSE;
@@ -650,6 +735,26 @@ button_pressed_callback (GtkTreeView *treeview, GdkEventButton *event,
 		gtk_widget_set_sensitive (view->details->popup_trash, can_move_uri_to_trash (uri));
 		g_free (uri);
 		
+		volume = fm_tree_model_get_volume_for_root_node_file (view->details->child_model, view->details->popup_file);
+		if (volume) {
+			show_unmount = TRUE;
+			unmount_is_eject = eject_for_type (gnome_vfs_volume_get_device_type (volume));
+		} 
+		
+		gtk_label_set_text (GTK_LABEL (GTK_BIN (GTK_MENU_ITEM (view->details->popup_unmount))->child),
+				    unmount_is_eject? _("E_ject"):_("_Unmount Volume"));
+		gtk_label_set_use_underline (GTK_LABEL (GTK_BIN (GTK_MENU_ITEM (view->details->popup_unmount))->child),
+				    TRUE);
+		if (show_unmount) {
+			gtk_widget_show (view->details->popup_unmount_separator);
+			gtk_widget_show (view->details->popup_unmount);
+		} else {
+			gtk_widget_hide (view->details->popup_unmount_separator);
+			gtk_widget_hide (view->details->popup_unmount);
+		}		
+
+		g_object_ref (view);
+		
 		gnome_popup_menu_do_popup_modal (view->details->popup,
 						 NULL, NULL, event, NULL,
 						 GTK_WIDGET (treeview));
@@ -660,6 +765,8 @@ button_pressed_callback (GtkTreeView *treeview, GdkEventButton *event,
 		nautilus_file_unref (view->details->popup_file);
 		view->details->popup_file = NULL;
 		
+		g_object_unref (view);
+
 		return TRUE;
 	}
 
@@ -795,8 +902,8 @@ copy_or_cut_files (FMTreeView *view,
 	}
 	g_free (name);
 	
-	nautilus_view_report_status (NAUTILUS_VIEW (view),
-				     status_string);
+	nautilus_window_info_set_status (view->details->window,
+					 status_string);
 	g_free (status_string);
 }
 
@@ -864,8 +971,8 @@ paste_clipboard_data (FMTreeView *view,
 	}
 
 	if (item_uris == NULL|| destination_uri == NULL) {
-		nautilus_view_report_status (NAUTILUS_VIEW (view),
-					     _("There is nothing on the clipboard to paste."));
+		nautilus_window_info_set_status (view->details->window,
+						 _("There is nothing on the clipboard to paste."));
 	} else {
 		nautilus_file_operations_copy_move
 			(item_uris, NULL, destination_uri,
@@ -935,6 +1042,49 @@ fm_tree_view_properties_cb (GtkWidget *menu_item,
         nautilus_file_list_free (list);
 }
 
+static void
+volume_or_drive_unmounted_callback (gboolean succeeded,
+				    char *error,
+				    char *detailed_error,
+				    gpointer data)
+{
+	gboolean eject;
+
+	eject = GPOINTER_TO_INT (data);
+	if (!succeeded) {
+		if (eject) {
+			eel_show_error_dialog_with_details (error, NULL, 
+			                                    _("Eject Error"), detailed_error, NULL);
+		} else {
+			eel_show_error_dialog_with_details (error, NULL, 
+			                                    _("Unmount Error"), detailed_error, NULL);
+		}
+	}
+}
+
+
+static void
+fm_tree_view_unmount_cb (GtkWidget *menu_item,
+			    FMTreeView *view)
+{
+	NautilusFile *file = view->details->popup_file;
+	GnomeVFSVolume *volume;
+	
+	if (file == NULL) {
+		return;
+	}
+
+	volume = fm_tree_model_get_volume_for_root_node_file (view->details->child_model, file);
+	
+	if (volume != NULL) {
+		if (eject_for_type (gnome_vfs_volume_get_device_type (volume))) {
+			gnome_vfs_volume_eject (volume, volume_or_drive_unmounted_callback, GINT_TO_POINTER (TRUE));
+		} else {
+			gnome_vfs_volume_unmount (volume, volume_or_drive_unmounted_callback, GINT_TO_POINTER (FALSE));
+		}
+	}
+}
+
 static void
 create_popup_menu (FMTreeView *view)
 {
@@ -1059,7 +1209,22 @@ create_popup_menu (FMTreeView *view)
 	gtk_widget_show (menu_item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (popup), menu_item);
 	view->details->popup_properties = menu_item;
+
+	/* add the unmount separator menu item */
+	menu_item = gtk_separator_menu_item_new ();
+	gtk_widget_show (menu_item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (popup), menu_item);
+	view->details->popup_unmount_separator = menu_item;
 	
+	/* add the "Unmount" menu item */
+	menu_item = gtk_image_menu_item_new_with_label ("eject label");
+	g_signal_connect (menu_item, "activate",
+			  G_CALLBACK (fm_tree_view_unmount_cb),
+			  view);
+	gtk_widget_show (menu_item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (popup), menu_item);
+	view->details->popup_unmount = menu_item;
+
 	view->details->popup = popup;
 }
 
@@ -1071,6 +1236,7 @@ create_tree (FMTreeView *view)
 	GnomeVFSVolumeMonitor *volume_monitor;
 	char *home_uri;
 	GList *volumes, *l;
+	char *location;
 	
 	view->details->child_model = fm_tree_model_new ();
 	view->details->sort_model = GTK_TREE_MODEL_SORT
@@ -1083,11 +1249,11 @@ create_tree (FMTreeView *view)
 		 G_CALLBACK (row_loaded_callback),
 		 view, G_CONNECT_AFTER);
 	home_uri = gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
-	fm_tree_model_add_root_uri (view->details->child_model, home_uri, _("Home Folder"), "gnome-home");
+	fm_tree_model_add_root_uri (view->details->child_model, home_uri, _("Home Folder"), "gnome-home", NULL);
 	g_free (home_uri);
-	fm_tree_model_add_root_uri (view->details->child_model, "file:///", _("Filesystem"), "gnome-fs-directory");
+	fm_tree_model_add_root_uri (view->details->child_model, "file:///", _("Filesystem"), "gnome-fs-directory", NULL);
 #ifdef NOT_YET_USABLE
-	fm_tree_model_add_root_uri (view->details->child_model, "network:///", _("Network Neighbourhood"), "gnome-fs-network");
+	fm_tree_model_add_root_uri (view->details->child_model, "network:///", _("Network Neighbourhood"), "gnome-fs-network", NULL);
 #endif
 	
 	volume_monitor = gnome_vfs_get_volume_monitor ();
@@ -1149,7 +1315,7 @@ create_tree (FMTreeView *view)
 
 	gtk_widget_show (GTK_WIDGET (view->details->tree_widget));
 
-	gtk_container_add (GTK_CONTAINER (view->details->scrolled_window),
+	gtk_container_add (GTK_CONTAINER (view),
 			   GTK_WIDGET (view->details->tree_widget));
 
 	g_signal_connect_object (gtk_tree_view_get_selection (GTK_TREE_VIEW (view->details->tree_widget)), "changed",
@@ -1163,28 +1329,30 @@ create_tree (FMTreeView *view)
 			  "button_press_event", G_CALLBACK (button_pressed_callback),
 			  view);
 
-	schedule_show_selection (view);
+	location = nautilus_window_info_get_current_location (view->details->window);
+	schedule_select_and_show_location (view, location);
+	g_free (location);
 }
 
 static void
 update_filtering_from_preferences (FMTreeView *view)
 {
-	Nautilus_ShowHiddenFilesMode mode;
+	NautilusWindowShowHiddenFilesMode mode;
 	
 	if (view->details->child_model == NULL) {
 		return;
 	}
 
-	mode = nautilus_view_get_show_hidden_files_mode (NAUTILUS_VIEW (view));
+	mode = nautilus_window_info_get_hidden_files_mode (view->details->window);
 
-	if (mode == Nautilus_SHOW_HIDDEN_FILES_DEFAULT) {
+	if (mode == NAUTILUS_WINDOW_SHOW_HIDDEN_FILES_DEFAULT) {
 		fm_tree_model_set_show_hidden_files
 			(view->details->child_model,
 			 eel_preferences_get_boolean (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES));
 	} else {
 		fm_tree_model_set_show_hidden_files
 			(view->details->child_model,
-			 mode == Nautilus_SHOW_HIDDEN_FILES_ENABLE);
+			 mode == NAUTILUS_WINDOW_SHOW_HIDDEN_FILES_ENABLE);
 	}
 	fm_tree_model_set_show_backup_files
 		(view->details->child_model,
@@ -1195,13 +1363,15 @@ update_filtering_from_preferences (FMTreeView *view)
 }
 
 static void
-tree_activate_callback (BonoboControl *control, gboolean activating, gpointer user_data)
+parent_set_callback (GtkWidget        *widget,
+		     GtkWidget        *previous_parent,
+		     gpointer          callback_data)
 {
 	FMTreeView *view;
 
-	view = FM_TREE_VIEW (user_data);
+	view = FM_TREE_VIEW (callback_data);
 
-	if (activating && view->details->tree_widget == NULL) {
+	if (widget->parent != NULL && view->details->tree_widget == NULL) {
 		create_tree (view);
 		update_filtering_from_preferences (view);
 	}
@@ -1214,41 +1384,31 @@ filtering_changed_callback (gpointer callback_data)
 }
 
 static void
-load_location_callback (FMTreeView *view, char *location)
+loading_uri_callback (NautilusWindowInfo *window,
+		      char *location,
+		      FMTreeView *view)
 {
-	if (view->details->selection_location != NULL) {
-		g_free (view->details->selection_location);
-	}
-	view->details->selection_location = g_strdup (location);
-
-	schedule_show_selection (view);
+	schedule_select_and_show_location (view, location);
 }
 
 static void
-fm_tree_view_instance_init (FMTreeView *view)
+fm_tree_view_init (FMTreeView *view)
 {
-	BonoboControl *control;
-	
 	view->details = g_new0 (FMTreeViewDetails, 1);
 	
-	
-	view->details->scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-	
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (view->details->scrolled_window), 
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (view), 
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_hadjustment (GTK_SCROLLED_WINDOW (view), NULL);
+	gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (view), NULL);
 	
-	gtk_widget_show (view->details->scrolled_window);
+	gtk_widget_show (GTK_WIDGET (view));
 
-	control = bonobo_control_new (view->details->scrolled_window);
-	g_signal_connect_object (control, "activate",
-				 G_CALLBACK (tree_activate_callback), view, 0);
-
-	nautilus_view_construct_from_bonobo_control (NAUTILUS_VIEW (view), control);
+	g_signal_connect_object (view, "parent_set",
+				 G_CALLBACK (parent_set_callback), view, 0);
 
 	view->details->selection_location = NULL;
-	g_signal_connect_object (view, "load_location",
-				 G_CALLBACK (load_location_callback), view, 0);
+	
 	view->details->selecting = FALSE;
 
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES,
@@ -1257,13 +1417,6 @@ fm_tree_view_instance_init (FMTreeView *view)
 				      filtering_changed_callback, view);
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_TREE_SHOW_ONLY_DIRECTORIES,
 				      filtering_changed_callback, view);
-	g_signal_connect_object (view, "show_hidden_files_mode_changed",
-				 G_CALLBACK (filtering_changed_callback), view, 0);  
-
-	nautilus_view_set_listener_mask
-		(NAUTILUS_VIEW (view),
-		 NAUTILUS_VIEW_LISTEN_SHOW_HIDDEN_FILES_MODE);
-
 	
 	g_signal_connect_object (nautilus_icon_factory_get(), "icons_changed",
 				 G_CALLBACK (theme_changed_callback), view, 0);  
@@ -1279,6 +1432,11 @@ fm_tree_view_dispose (GObject *object)
 	
 	view = FM_TREE_VIEW (object);
 	
+	if (view->details->selection_changed_timer) {
+		g_source_remove (view->details->selection_changed_timer);
+		view->details->selection_changed_timer = 0;
+	}
+
 	if (view->details->drag_dest) {
 		g_object_unref (view->details->drag_dest);
 		view->details->drag_dest = NULL;
@@ -1326,3 +1484,100 @@ fm_tree_view_class_init (FMTreeViewClass *class)
 	
 	copied_files_atom = gdk_atom_intern ("x-special/gnome-copied-files", FALSE);
 }
+
+static const char *
+fm_tree_view_get_sidebar_id (NautilusSidebar *sidebar)
+{
+	return TREE_SIDEBAR_ID;
+}
+
+static char *
+fm_tree_view_get_tab_label (NautilusSidebar *sidebar)
+{
+	return g_strdup (_("Tree"));
+}
+
+static GdkPixbuf *
+fm_tree_view_get_tab_icon (NautilusSidebar *sidebar)
+{
+	return NULL;
+}
+
+static void
+fm_tree_view_is_visible_changed (NautilusSidebar *sidebar,
+				 gboolean         is_visible)
+{
+	/* Do nothing */
+}
+
+static void 
+hidden_files_mode_changed_callback (NautilusWindowInfo *window,
+				    FMTreeView *view)
+{
+	update_filtering_from_preferences (view);
+}
+
+static void
+fm_tree_view_iface_init (NautilusSidebarIface *iface)
+{
+	iface->get_sidebar_id = fm_tree_view_get_sidebar_id;
+	iface->get_tab_label = fm_tree_view_get_tab_label;
+	iface->get_tab_icon = fm_tree_view_get_tab_icon;
+	iface->is_visible_changed = fm_tree_view_is_visible_changed;
+}
+
+static void
+fm_tree_view_set_parent_window (FMTreeView *sidebar,
+				NautilusWindowInfo *window)
+{
+	char *location;
+	
+	sidebar->details->window = window;
+
+	g_signal_connect_object (window, "loading_uri",
+				 G_CALLBACK (loading_uri_callback), sidebar, 0);
+	location = nautilus_window_info_get_current_location (window);
+	loading_uri_callback (window, location, sidebar);
+	g_free (location);
+
+	g_signal_connect_object (window, "hidden_files_mode_changed",
+				 G_CALLBACK (hidden_files_mode_changed_callback), sidebar, 0);  
+
+}
+
+static NautilusSidebar *
+fm_tree_view_create (NautilusSidebarProvider *provider,
+		     NautilusWindowInfo *window)
+{
+	FMTreeView *sidebar;
+	
+	sidebar = g_object_new (fm_tree_view_get_type (), NULL);
+	fm_tree_view_set_parent_window (sidebar, window);
+	g_object_ref (sidebar);
+	gtk_object_sink (GTK_OBJECT (sidebar));
+
+	return NAUTILUS_SIDEBAR (sidebar);
+}
+
+static void 
+sidebar_provider_iface_init (NautilusSidebarProviderIface *iface)
+{
+	iface->create = fm_tree_view_create;
+}
+
+static void
+fm_tree_view_provider_init (FMTreeViewProvider *sidebar)
+{
+}
+
+static void
+fm_tree_view_provider_class_init (FMTreeViewProviderClass *class)
+{
+}
+
+void
+fm_tree_view_register (void)
+{
+        nautilus_module_add_type (fm_tree_view_provider_get_type ());
+}
+
