@@ -28,7 +28,7 @@
 #include <config.h>
 #include "nautilus-bookmarks-window.h"
 #include "nautilus-window.h"
-#include <libnautilus/nautilus-undo.h>
+#include <libnautilus-private/nautilus-undo.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gnome-extensions.h>
