@@ -36,7 +36,6 @@
 #include "nautilus-window.h"
 #include <bonobo-activation/bonobo-activation.h>
 #include <bonobo/bonobo-main.h>
-#include <bonobo/bonobo-ui-main.h>
 #include <dlfcn.h>
 #include <eel/eel-debug.h>
 #include <eel/eel-glib-extensions.h>
@@ -256,7 +255,9 @@ main (int argc, char *argv[])
 	/* Check for argument consistency. */
 	args = poptGetArgs (popt_context);
 	if (perform_self_check && args != NULL) {
-		fprintf (stderr, _("nautilus: --check cannot be used with URIs.\n"));
+		/* translators: %s is an option (e.g. --check) */
+		fprintf (stderr, _("nautilus: %s cannot be used with URIs.\n"),
+			"--check");
 		return EXIT_FAILURE;
 	}
 	if (perform_self_check && (kill_shell || restart_shell)) {
@@ -264,11 +265,13 @@ main (int argc, char *argv[])
 		return EXIT_FAILURE;
 	}
 	if (kill_shell && args != NULL) {
-		fprintf (stderr, _("nautilus: --quit cannot be used with URIs.\n"));
+		fprintf (stderr, _("nautilus: %s cannot be used with URIs.\n"),
+			"--quit");
 		return EXIT_FAILURE;
 	}
 	if (restart_shell && args != NULL) {
-		fprintf (stderr, _("nautilus: --restart cannot be used with URIs.\n"));
+		fprintf (stderr, _("nautilus: %s cannot be used with URIs.\n"),
+			"--restart");
 		return EXIT_FAILURE;
 	}
 	if (geometry != NULL && args != NULL && args[0] != NULL && args[1] != NULL) {
@@ -279,15 +282,11 @@ main (int argc, char *argv[])
 	/* Initialize the services that we use. */
 	LIBXML_TEST_VERSION
 
-	if (g_getenv ("NAUTILUS_ENABLE_TEST_COMPONENTS") != NULL) {
-		bonobo_activation_set_test_components_enabled (TRUE);
-	}
-
 	/* Initialize preferences. This is needed so that proper 
 	 * defaults are available before any preference peeking 
 	 * happens.
 	 */
-	nautilus_global_preferences_init_with_folder_browsing ();
+	nautilus_global_preferences_init ();
 	if (no_desktop) {
 		eel_preferences_set_is_invisible
 			(NAUTILUS_PREFERENCES_SHOW_DESKTOP, TRUE);
@@ -341,7 +340,6 @@ main (int argc, char *argv[])
 	}
 
 	eel_debug_shut_down ();
-	bonobo_ui_debug_shutdown ();
 
 	/* If told to restart, exec() myself again. This is used when
 	 * the program is told to restart with CORBA, for example when
