@@ -143,17 +143,14 @@ open_window (NautilusShell *shell, const char *uri, const char *geometry,
 	} else {
 		home_uri = NULL;
 		if (uri == NULL) {
-#ifdef WEB_NAVIGATION_ENABLED
-			home_uri = eel_preferences_get (NAUTILUS_PREFERENCES_HOME_URI);
-#else
 			home_uri = gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
-#endif
 			uri = home_uri;
 		}
 		
 		window = nautilus_application_present_spatial_window (shell->details->application,
-								     uri,
-								     gdk_screen_get_default ());
+								      NULL,
+								      uri,
+								      gdk_screen_get_default ());
 		g_free (home_uri);
 	}
 	
@@ -347,6 +344,7 @@ restore_one_window_callback (const char *attributes,
 #endif
 	if (eel_strlen (location) > 0) {
 		window = nautilus_application_present_spatial_window (shell->details->application, 
+								      NULL,
 								      location,
 								      screen);
 	} else {
